@@ -4,7 +4,7 @@ module.exports = function(RED) {
     function LinkNode(config) {
         RED.nodes.createNode(this, config);
         var node = this;
-        var done = ui.addLink(config.name, config.link, config.icon, config.order, config.target);
+        var done = ui.addLink(config.name, config.link, config.icon, config.order, config.target, config.className);
         node.on("close", done);
     }
 
