@@ -135,7 +135,7 @@ module.exports = function(RED) {
             },
             beforeSend: function (msg) {
                 var t = RED.util.evaluateNodeProperty(config.topic,config.topicType || "str",node,msg) || node.topi;
-                if (t) { msg.topic = t; }
+                if (t !== undefined) { msg.topic = t; }
             }
         });
 
