@@ -25,6 +25,7 @@ module.exports = function(RED) {
 var fs = require('fs');
 var path = require('path');
 var events = require('events');
+var process = require('process');
 var socketio = require('socket.io');
 var serveStatic = require('serve-static');
 var compression = require('compression');
@@ -368,7 +369,12 @@ function init(server, app, log, redSettings) {
         }
     });
 
-    log.info("Dashboard version " + dashboardVersion + " started at " + fullPath);
+    if ( process.versions.node.split('.')[0] < 12 ) {
+        log.error("Dashboard version "+dashboardVersion+" requires Nodejs 12 or more recent");
+    }
+    else {
+        log.info("Dashboard version " + dashboardVersion + " started at " + fullPath);
+    }
 
     if (typeof uiSettings.ioMiddleware === "function") {
         io.use(uiSettings.ioMiddleware);
@@ -392,8 +398,7 @@ function init(server, app, log, redSettings) {
     }
 
     io.on('connection', function(socket) {
-
-        ev.emit("newsocket", socket.client.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress);
+        ev.emit("newsocket", socket.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress);
         updateUi(socket);
 
         socket.on(updateValueEventName, ev.emit.bind(ev, updateValueEventName));
@@ -410,20 +415,20 @@ function init(server, app, log, redSettings) {
             var name = "";
             if ((index != null) && !isNaN(index) && (menu.length > 0) && (index < menu.length) && menu[index]) {
                 name = (menu[index].hasOwnProperty("header") && typeof menu[index].header !== 'undefined') ? menu[index].header : menu[index].name;
-                ev.emit("changetab", index, name, socket.client.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress, params);
+                ev.emit("changetab", index, name, socket.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress, params);
             }
         });
         socket.on('ui-collapse', function(d) {
-            ev.emit("collapse", d.group, d.state, socket.client.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress);
+            ev.emit("collapse", d.group, d.state, socket.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress);
         });
         socket.on('ui-refresh', function() {
             updateUi();
         });
         socket.on('disconnect', function() {
-            ev.emit("endsocket", socket.client.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress);
+            ev.emit("endsocket", socket.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress);
         });
         socket.on('ui-audio', function(audioStatus) {
-            ev.emit("audiostatus", audioStatus, socket.client.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress);
+            ev.emit("audiostatus", audioStatus, socket.id, socket.request.headers['x-real-ip'] || socket.request.headers['x-forwarded-for'] || socket.request.connection.remoteAddress);
         });
         socket.on('ui-params', function(p) {
             delete p.socketid;
